@@ -14,10 +14,13 @@
 
 from __future__ import annotations
 
+from typing import Union
+
 from .. import ValueObject
 from ..entity import required, optional
 
 
 class File(ValueObject):
     name: str = required()
-    content: str = optional()
+    content: Union[bytes, str] = optional()  # Base64-Encoded
+    content_type: str = optional()
